==> ?f=K2_v2.0.0.zip: modules/mod_k2_login/helper.php <==
<?php
/*
// "K2 Login" Module by JoomlaWorks for Joomla! 1.5.x - Version 2.0
// Copyright (c) 2006 - 2009 JoomlaWorks Ltd. All rights reserved.
// Released under the GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
// More info at http://www.joomlaworks.gr and http://k2.joomlaworks.gr
// Designed and developed by the JoomlaWorks team
// *** Last update: August 6th, 2009 ***
*/

// no direct access
defined('_JEXEC') or die ('Restricted access');

require_once (JPATH_SITE.DS.'components'.DS.'com_k2'.DS.'helpers'.DS.'route.php');
require_once (JPATH_SITE.DS.'components'.DS.'com_k2'.DS.'helpers'.DS.'utilities.php');

class modK2LoginHelper {
	
	function getReturnURL($params, $type) {
	
		if($itemid =  $params->get($type))
		{
			$menu =& JSite::getMenu();
			$item = $menu->getItem($itemid);
			$url = JRoute::_($item->link.'&Itemid='.$itemid, false);
		}
		else
		{
			// stay on the same page
			$uri = JFactory::getURI();
			$url = $uri->toString(array('path', 'query', 'fragment'));
		}

		return base64_encode($url);
	}

	function getType() {
	
		$user = & JFactory::getUser();
		return (!$user->get('guest')) ? 'logout' : 'login';
	}

	function getProfile( & $params) {
	
		$user = &JFactory::getUser();
		$db = & JFactory::getDBO();
		$query = "SELECT * FROM #__k2_users  WHERE userID={$user->id}";
		$db->setQuery($query, 0, 1);
		$profile = $db->loadObject();
		
		if ($profile){
			if ($profile->image!='')
			$profile->avatar = JURI::root().'media/k2/users/'.$profile->image;
			
			require_once (JPATH_SITE.DS.'components'.DS.'com_k2'.DS.'helpers'.DS.'permissions'.'.php');
			
			if (JRequest::getCmd('option')!='com_k2')
			K2HelperPermissions::setPermissions();
			
			if(K2HelperPermissions::canAddItem())
			$profile->addLink = JRoute::_('index.php?option=com_k2&view=item&task=add&tmpl=component');

			return $profile;		
			
		}

	}
	
	function countUserComments( $userID ) {
	
		$db = & JFactory::getDBO();
		$query = "SELECT COUNT(*) FROM #__k2_comments WHERE userID={$userID} AND published=1";
		$db->setQuery($query);
		$result = $db->loadResult();
		return $result;

	}

}

==> ?f=K2_v2.2.0.zip: modules/mod_k2_login/helper.php <==
<?php
/**
 * @version		$Id: helper.php 307 2010-01-11 20:58:54Z joomlaworks $
 * @package		K2
 * @author    JoomlaWorks http://www.joomlaworks.gr
 * @copyright	Copyright (c) 2006 - 2010 JoomlaWorks Ltd. All rights reserved.
 * @license		GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
 */
// no direct access
defined('_JEXEC') or die('Restricted access');

require_once (JPATH_SITE.DS.'components'.DS.'com_k2'.DS.'helpers'.DS.'route.php');
require_once (JPATH_SITE.DS.'components'.DS.'com_k2'.DS.'helpers'.DS.'utilities.php');

class modK2LoginHelper {
	
	function getReturnURL($params, $type) {
	
		if($itemid =  $params->get($type))
		{
			$menu =& JSite::getMenu();
			$item = $menu->getItem($itemid);
			$url = JRoute::_($item->link.'&Itemid='.$itemid, false);
		}
		else
		{
			// stay on the same page
			$uri = JFactory::getURI();
			$url = $uri->toString(array('path', 'query', 'fragment'));
		}

		return base64_encode($url);
	}

	function getType() {
	
		$user = & JFactory::getUser();
		return (!$user->get('guest')) ? 'logout' : 'login';
	}

	function getProfile( & $params) {
	
		$user = &JFactory::getUser();
		$db = & JFactory::getDBO();
		$query = "SELECT * FROM #__k2_users  WHERE userID={$user->id}";
		$db->setQuery($query, 0, 1);
		$profile = $db->loadObject();
		
		if ($profile){
			if ($profile->image!='')
			$profile->avatar = JURI::root().'media/k2/users/'.$profile->image;
			
			require_once (JPATH_SITE.DS.'components'.DS.'com_k2'.DS.'helpers'.DS.'permissions'.'.php');
			
			if (JRequest::getCmd('option')!='com_k2')
			K2HelperPermissions::setPermissions();
			
			if(K2HelperPermissions::canAddItem())
			$profile->addLink = JRoute::_('index.php?option=com_k2&view=item&task=add&tmpl=component');

			return $profile;		
			
		}

	}
	
	function countUserComments( $userID ) {
	
		$db = & JFactory::getDBO();
		$query = "SELECT COUNT(*) FROM #__k2_comments WHERE userID={$userID} AND published=1";
		$db->setQuery($query);
		$result = $db->loadResult();
		return $result;

	}

}
